@@ -23,6 +23,7 @@
 #include <config.h>
 
 #include <sstream>
+#include <iomanip>
 
 #include "RGBColorAux.hh"
 
@@ -30,13 +31,14 @@ std::string
 toString(const RGBColor& color)
 {
   std::ostringstream os;
-  if (color.transparent)
+  if (color.transparent())
     os << "transparent";
   else
     {
-      os.width(2);
-      os.fill('0');
-      os << "#" << std::hex << color.red << color.green << color.blue;
+      os << "#"
+	 << std::setw(2) << std::setfill('0') << std::hex << (static_cast<unsigned>(color.red) & 0xff)
+	 << std::setw(2) << std::setfill('0') << std::hex << (static_cast<unsigned>(color.green) & 0xff)
+	 << std::setw(2) << std::setfill('0') << std::hex << (static_cast<unsigned>(color.blue) & 0xff);
     }
   return os.str();
 }
